@@ -14,16 +14,17 @@ __all__ = [
     "run",
     "gather",
     "switch",
+    "asleep",
     "new_task",
     "new_future",
 ]
 
 
 __doc__ = """
-A collection of asyncio & uvloop references to simplify the standard
-usage of those libraries in this package. This module can be used to
-replace the default event loop policy, for instance, to run uvloop. The
-default asyncio loop is still available in ``default_loop``.
+A collection of asyncio & concurrency references to simplify their
+standard usage in this package. This module can be used to replace the
+default event loop policy, for instance, to run uvloop or change async
+frameworks. The default asyncio loop is available in ``default_loop``.
 """
 
 
@@ -33,9 +34,13 @@ from time import time
 from time import sleep
 from functools import wraps
 from functools import partial
-from .commons import commons
+from concurrent.futures import ThreadPoolExecutor
+from concurrent.futures import ProcessPoolExecutor
+from .commons import Namespace
 
 
+thread_pool = ThreadPoolExecutor()
+process_pool = ProcessPoolExecutor()
 default_loop = asyncio.get_event_loop()
 
 
@@ -99,7 +104,7 @@ def stop():
     return loop().stop()
 
 
-def executor_wrapper(function):
+def wrap_in_executor(function):
     """
     A decorator that wraps synchronous blocking IO functions so they
     will run in an executor. This was adapted from the ``aiofiles``
@@ -136,13 +141,13 @@ def make_os_async(namespace=None):
     http://www.apache.org/licenses/LICENSE-2.0
     """
     if namespace == None:
-        namespace = commons.Namespace()
+        namespace = Namespace()
     attrs = [
         "sendfile", "stat", "rename", "remove", "mkdir", "makedirs", "rmdir"
     ]
     for attr in attrs:
         if hasattr(os, attr):
-            setattr(namespace, attr, executor_wrapper(getattr(os, attr)))
+            setattr(namespace, attr, wrap_in_executor(getattr(os, attr)))
     return namespace
 
 
@@ -180,10 +185,12 @@ __extras = {
     "gather": gather,
     "new_task": new_task,
     "new_future": new_future,
+    "thread_pool": thread_pool,
+    "process_pool": process_pool,
     "default_loop": default_loop,
-    "executor_wrapper": executor_wrapper,
+    "wrap_in_executor": wrap_in_executor,
 }
 
 
-asynchs = commons.Namespace.make_module("asynchs", mapping=__extras)
+asynchs = Namespace.make_module("asynchs", mapping=__extras)
 
